# Authors

The following people have contributed to `bruges`:

- [Alessandro Amato del Monte](https://github.com/aadm), ENI, Italy
- [Evan Bianco](https://github.com/EvanBianco), Agile Scientific, Canada
- [Ben Bougher](https://github.com/ben-bougher), Canada
- [Jesper Dramsch](https://github.com/JesperDramsch), Edinburgh, UK
- [Matt Hall](https://github.com/kwinkunks), Agile Scientific, Canada / [ORCID: 0000-0002-4054-8295]( https://orcid.org/0000-0002-4054-8295))
- [Wes Hamlyn](https://github.com/whamlyn), Canada
- [Kent Inverarity](https://github.com/kinverarity1), South Australia
- [Matteo Niccoli](https://github.com/mycarta), Calgary, Canada
- [Jesse Pisel](https://github.com/jessepisel), USA
- [Sean Ross-Ross](https://github.com/srossross), Vancouver, Canada
- [Leonardo Uieda](https://github.com/leouieda), Liverpool, UK
